@@ -35,9 +35,6 @@
 #' # Just vernacular (common) names
 #' name_lookup(query='Cnaemidophorus', rank="genus", return="names")
 #'
-#' # Fuzzy searching
-#' name_lookup(query='Cnaemidophor', rank="genus")
-#'
 #' # Limit records to certain number
 #' name_lookup('Helianthus annuus', rank="species", limit=2)
 #'
@@ -75,9 +72,10 @@
 #' name_lookup(query='Cnaemidophorus', rank="genus", config=verbose())
 #' }
 
-name_lookup <- function(query=NULL, rank=NULL, higherTaxonKey=NULL, status=NULL, isExtinct=NULL,
-  habitat=NULL, nameType=NULL, datasetKey=NULL, nomenclaturalStatus=NULL,
-  limit=100, start=NULL, facet=NULL, facetMincount=NULL, facetMultiselect=NULL, type=NULL, hl=NULL,
+name_lookup <- function(query=NULL, rank=NULL, higherTaxonKey=NULL, status=NULL,
+  isExtinct=NULL, habitat=NULL, nameType=NULL, datasetKey=NULL,
+  nomenclaturalStatus=NULL, limit=100, start=NULL, facet=NULL,
+  facetMincount=NULL, facetMultiselect=NULL, type=NULL, hl=NULL,
   verbose=FALSE, return="all", ...) {
 
   if (!is.null(facetMincount) && inherits(facetMincount, "numeric"))
@@ -90,8 +88,9 @@ name_lookup <- function(query=NULL, rank=NULL, higherTaxonKey=NULL, status=NULL,
   }
 
   url <- paste0(gbif_base(), '/species/search')
-  args <- rgbif_compact(list(q=query, rank=rank, higherTaxonKey=higherTaxonKey, status=status,
-            isExtinct=as_log(isExtinct), habitat=habitat, nameType=nameType, datasetKey=datasetKey,
+  args <- rgbif_compact(list(q=query, rank=rank, higherTaxonKey=higherTaxonKey,
+            status=status, isExtinct=as_log(isExtinct), habitat=habitat,
+            nameType=nameType, datasetKey=datasetKey,
             nomenclaturalStatus=nomenclaturalStatus, limit=limit, offset=start,
             facetMincount=facetMincount,
             facetMultiselect=as_log(facetMultiselect), hl=as_log(hl), type=type))
